unit FrmOscSetup;

interface

uses

  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.Buttons, System.IniFiles, WinApi.ShellAPI,

  Globals;


type

  TOnSendOscTestMessage = procedure( const aSender: TObject) of object;

  TFormOscSetup = class(TForm)
    BitBtnOk: TBitBtn;
    BitBtnCancel: TBitBtn;
    BitBtnSendOSCTestMessage: TBitBtn;
    LabelIpAddress: TLabel;
    LabelPort: TLabel;
    EditOSCServer: TEdit;
    EditOSCPort: TEdit;
    CheckBoxOscActive: TCheckBox;
    BitBtnHelp: TBitBtn;
    procedure EditOSCServerChange(Sender: TObject);
    procedure EditOSCPortChange(Sender: TObject);
    procedure CheckBoxOscActiveClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure BitBtnSendOSCTestMessageClick(Sender: TObject);
    procedure BitBtnHelpClick(Sender: TObject);
    procedure BitBtnOkKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
  private
    FOScServer            : string;      FOldOScServer : string;
    FOscPort              : string;      FOldOscPort   : string;
    FOscActive            : Boolean;     FOldOscActive : Boolean;
    FHelpUrl              : string;
    FOnSendOscTestMessage : TOnSendOscTestMessage;
  private
    procedure   SetOscServer( const aValue: string );
    procedure   SetOscPort  ( const aValue: string );
    procedure   SetOscActive(       aValue: Boolean);
  private
    procedure   SaveSettings;
    procedure   RestoreSettings;
    procedure   SendTestMessage;
    procedure   ShowHelp;
  public
    procedure   SaveToIni  ( anIniFile: TCustomIniFile; const aSection: string);
    procedure   LoadFromIni( anIniFile: TCustomIniFile; const aSection: string);
    procedure   Initialize;
    function    Execute: Boolean;
  public
    property    OscServer            : string                read FOscServer            write SetOscServer;
    property    OscPort              : string                read FOscPort              write SetOscPort;
    property    OscActive            : Boolean               read FOScActive            write SetOscActive;
    property    OnSendOscTestMessage : TOnSendOscTestMessage read FOnSendOscTestMessage write FOnSendOscTestMessage;
  end;

var

  FormOscSetup: TFormOscSetup;


implementation


// User area

//  private

    procedure   TFormOscSetup.SetOscServer( const aValue: string);
    begin
      if   aValue <> FOscServer
      then begin
        FOScServer         := aValue;
        EditOScServer.Text := aValue;
      end;
    end;


    procedure   TFormOscSetup.SetOscPort  ( const aValue: string);
    begin
      if   aValue <> FOscPort
      then begin
        FOScPort         := aValue;
        EditOScPort.Text := aValue;
      end;
    end;


    procedure   TFormOscSetup.SetOscActive( aValue: Boolean);
    begin
      if   aValue <> FOscActive
      then begin
        FOScActive                := aValue;
        CheckBoxOscActive.Checked := aValue;
      end;
    end;


//  private

    procedure   TFormOscSetup.SaveSettings;
    begin
      FOldOScServer := OscServer;
      FOldOscPort   := OscPort;
      FOldOscActive := OscActive;
    end;


    procedure   TFormOscSetup.RestoreSettings;
    begin
      OscServer := FOldOscServer;
      OscPort   := FOldOscPort;
      OscActive := FOldOscActive;
    end;


    procedure   TFormOscSetup.SendTestMessage;
    begin
      if   Assigned( FOnSendOscTestMessage)
      then FOnSendOscTestMessage( Self);
    end;


    procedure   TFormOscSetup.ShowHelp;
    begin
      ShellExecute(
        Handle,
        Nil,
        PChar( FHelpUrl),
        Nil,
        Nil,
        SW_SHOWNORMAL
      );
    end;


//  public

    procedure   TFormOscSetup.SaveToIni( anIniFile: TCustomIniFile; const aSection: string);
    begin
      if   Assigned( anIniFile)
      and  ( aSection <> '')
      then begin
        anIniFile.EraseSection( aSection);
        anIniFile.WriteInteger( aSection, 'Left'     , Left     );
        anIniFile.WriteInteger( aSection, 'Top'      , Top      );
        anIniFile.WriteInteger( aSection, 'Width'    , Width    );
        anIniFile.WriteInteger( aSection, 'Height'   , Height   );
        anIniFile.WriteString ( aSection, 'OscServer', OScServer);
        anIniFile.WriteString ( aSection, 'OscPort'  , OScPort  );
        anIniFile.WriteBool   ( aSection, 'OscActive', OScActive);
      end;
    end;


    procedure   TFormOscSetup.LoadFromIni( anIniFile: TCustomIniFile; const aSection: string);
    var
      L, T, W, H : Integer;
    begin
      if   Assigned( anIniFile)
      and  ( aSection <> '')
      then begin
        OscServer := anIniFile.ReadString ( aSection, 'OscServer', OScServer);
        OscPort   := anIniFile.ReadString ( aSection, 'OscPort'  , OScPort  );
        OscActive := anIniFile.ReadBool   ( aSection, 'OscActive', OScActive);
        L         := anIniFile.ReadInteger( aSection, 'Left'     , Left     );
        T         := anIniFile.ReadInteger( aSection, 'Top'      , Top      );
        W         := anIniFile.ReadInteger( aSection, 'Width'    , Width    );
        H         := anIniFile.ReadInteger( aSection, 'Height'   , Height   );

        if ( L < 0) or ( L > Screen.Width  - 10) then L := 0;
        if ( T < 0) or ( T > Screen.Height - 10) then T := 0;
        if W > Screen.Width                      then W := Screen.Width ;
        if H > Screen.Height                     then H := Screen.Height;

        SetBounds( L, T, W, H);
      end;
    end;


    procedure   TFormOscSetup.Initialize;
    begin
      FHelpUrl := BaseURL + '#faqosc';
      BitBtnHelp.Hint := 'Opens up ' + FHelpUrl + 'in your web browser';
      OscServer := '';
      OscPort   := '31415';
      OscActive := False;
    end;


    function    TFormOscSetup.Execute: Boolean;
    begin
      SaveSettings;
      Result := ShowModal = mrOk;

      if   not Result
      then RestoreSettings;
    end;



// Delphi area

{$R *.dfm}

procedure TFormOscSetup.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  if   ModalResult <> mrOk
  then RestoreSettings;
end;

procedure TFormOscSetup.BitBtnHelpClick(Sender: TObject);
begin
  ShowHelp;
end;

procedure TFormOscSetup.BitBtnOkKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
begin
  if   Key = VK_ESCAPE
  then begin
    ModalResult := mrCancel;
    Key         := 0;
  end
  else if Key = VK_RETURN
  then begin
    ModalResult := mrOk;
    Key         := 0;
  end
end;

procedure TFormOscSetup.BitBtnSendOSCTestMessageClick(Sender: TObject);
begin
  SendTestMessage;
end;

procedure TFormOscSetup.CheckBoxOscActiveClick(Sender: TObject);
begin
  OscActive := CheckBoxOscActive.Checked;
end;

procedure TFormOscSetup.EditOSCPortChange(Sender: TObject);
begin
  OscPort := EditOScPort.Text;
end;

procedure TFormOscSetup.EditOSCServerChange(Sender: TObject);
begin
  OscServer := EditOscServer.Text;
  BitBtnSendOSCTestMessage.Visible := OscServer <> '';
end;

end.

